@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for openSUSE 12.1's 3.1.0 kernel.
+# This is a kernel build script for openSUSE 11.3's 2.6.34 kernel.
 #
 
 die () {
@@ -60,24 +60,24 @@ fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-source-3.1.0-1.1.1.src.rpm ]
+if [ ! -r kernel-source-2.6.34.10-0.4.1.src.rpm ]
 then
-    wget http://download.opensuse.org/factory-snapshot/repo/source/suse/src/kernel-source-3.1.0-1.1.1.src.rpm || die "Can't download source package."
+    wget http://download.opensuse.org/update/11.3/rpm/src/kernel-source-2.6.34.10-0.4.1.src.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-source-3.1.0-1.1.1.src.rpm || die "Can't verify signature."
-rpm -ivh kernel-source-3.1.0-1.1.1.src.rpm || die "Can't install source package."
+rpm --checksig kernel-source-2.6.34.10-0.4.1.src.rpm || die "Can't verify signature."
+rpm -ivh kernel-source-2.6.34.10-0.4.1.src.rpm || die "Can't install source package."
 
-if [ ! -r kernel-default-3.1.0-1.1.2.nosrc.rpm ]
+if [ ! -r kernel-default-2.6.34.10-0.4.1.nosrc.rpm ]
 then
-    wget http://download.opensuse.org/factory-snapshot/repo/source/suse/nosrc/kernel-default-3.1.0-1.1.2.nosrc.rpm || die "Can't download source package."
+    wget http://download.opensuse.org/update/11.3/rpm/src/kernel-default-2.6.34.10-0.4.1.nosrc.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-default-3.1.0-1.1.2.nosrc.rpm || die "Can't verify signature."
-rpm -ivh kernel-default-3.1.0-1.1.2.nosrc.rpm || die "Can't install source package."
+rpm --checksig kernel-default-2.6.34.10-0.4.1.nosrc.rpm || die "Can't verify signature."
+rpm -ivh kernel-default-2.6.34.10-0.4.1.nosrc.rpm || die "Can't install source package."
 
 cd /usr/src/packages/SOURCES/ || die "Can't chdir to /usr/src/packages/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.3-20111118.tar.gz ]
+if [ ! -r ccs-patch-1.8.3-20111213.tar.gz ]
 then
-    wget -O ccs-patch-1.8.3-20111118.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20111118.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.3-20111213.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20111213.tar.gz' || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
@@ -92,24 +92,24 @@ patch << "EOF" || die "Can't patch spec file."
 -Name:           kernel-default
 +Name:           ccs-kernel-default
  Summary:        The Standard Kernel
- Version:        3.1.0
--Release:        1.1.2
-+Release:        1.1.2_tomoyo_1.8.3p3
- License:        GPL v2 only
- Group:          System/Kernel
- Url:            http://www.kernel.org/
-@@ -303,6 +303,11 @@
+ Version:        2.6.34.10
+-Release:        0.4.1
++Release:        0.4.1_tomoyo_1.8.3p4
+ %if %using_buildservice
+ %else
+ %endif
+@@ -306,6 +306,11 @@
  %endif
  	%_sourcedir/series.conf .. $SYMBOLS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.8.3-20111118.tar.gz
-+patch -sp1 < patches/ccs-patch-3.1.diff
++tar -zxf %_sourcedir/ccs-patch-1.8.3-20111213.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.34-suse-11.3.diff
 +cat config.ccs >> ../config/%cpu_arch_flavor
 +
  cd %kernel_build_dir
  
- # Override the timestamp 'uname -v' reports with the source timestamp and
+ if [ -f %_sourcedir/localversion ] ; then
 EOF
 sed -e 's:^Provides:#Provides:' -e 's:^Obsoletes:#Obsoletes:' -e 's:-n kernel:-n ccs-kernel:' kernel-default.spec > ccs-kernel.spec || die "Can't edit spec file."
 echo ""
